<?php
class Button_Grid_Module extends ET_Builder_Module
{
	protected $module_credits = [
		'module_uri' => 'https://makeweb.com.au',
		'author' => 'MakeWeb',
		'author_uri' => 'https://makeweb.com.au',
	];
	
	public function init()
	{
		parent::init();
		$this->name             = 'Button Grid';
		$this->version          = '1.1.1';
		$this->slug             = 'mw_button_grid';
		$this->fb_support       = 'partial';
		$this->child_slug 		= 'mw_button_grid_item';
		$this->main_css_element = '%%order_class%%';
	}

	public function get_settings_modal_toggles()
	{
		return [
			'general' => [
				'toggles' => [
					'flexbox' => esc_html__('Flex Settings', 'ratchet'),
				],
			],
			'advanced' => [
				'toggles' => [
					'text_style' => esc_html__('Text Style', 'ratchet'),
				],
			],
		];
	}
	
	public function get_custom_css_fields_config()
	{
		$fields = [];
		return $fields;
	}
	
	public function get_advanced_fields_config()
	{
		$advanced_fields = [];
		$advanced_fields["text"] = false;
		$advanced_fields["text_shadow"] = false;
	
		$advanced_fields['margin_padding'] = [
			'css' => [
				'margin' => '%%order_class%%',
				'padding' => '%%order_class%%',
				'important' => 'all',
			],
		];
	
		$advanced_fields['fonts']['text_style'] = [
			'css' => [
				'main' => "%%order_class%%",
				'important' => 'all',
			],
			'text_align' => [
				'default' => 'left',
			],
			'font_size' => [
				'default' => '16px',
				'range_settings' => [
					'min' => '1',
					'max' => '50',
					'step' => '1',
				],
			],
			'line_height' => [
				'default' => '1em',
				'range_settings' => [
					'min' => '1',
					'max' => '3',
					'step' => '0.1',
				],
			],
			'toggle_slug' => 'text_style',
		];
	
		$advanced_fields['button']["button_grid"] = [
			'label' => esc_html__('Button Style', 'ratchet'),
			'css' => [
				'main' => "%%order_class%% .dipi-button-wrap",
				'important' => 'all',
			],
			'hide_icon' => true,
			'use_alignment' => false,
			'box_shadow' => [
				'css' => [
					'main' => "%%order_class%% .dipi-button-wrap",
				],
			],
			'margin_padding' => [
				'css' => [
					'main' => "%%order_class%% .dipi-button-wrap",
					'important' => 'all',
				],
			],
		];
	
		return $advanced_fields;
	}

	public function get_fields()
	{
		$fields = [];
		
		$fields['flex_direction'] = [
			'label' => esc_html__('Direction', 'ratchet'),
			'type' => 'select',
			'option_category' => 'configuration',
			'default' => 'column',
			'options' => [
				'column' => esc_html__('Column', 'ratchet'),
				'row' => esc_html__('Row', 'ratchet'),
			],
			'mobile_options' => true,
			'toggle_slug' => 'flexbox',
		];
		
		$fields['flex_wrap'] = [
			'label' => esc_html__('Wrap', 'ratchet'),
			'type' => 'yes_no_button',
			'option_category' => 'configuration',
			'default' => 'on',
			'options' => [
				'on' => esc_html__('Yes', 'ratchet'),
				'off' => esc_html__('No', 'ratchet'),
			],
			'mobile_options' => true,
			'toggle_slug' => 'flexbox',
		];
		
		$fields['justify_content'] = [
			'label' => esc_html__('Justify Content', 'ratchet'),
			'type' => 'select',
			'option_category' => 'configuration',
			'default' => 'center',
			'options' => [
				'center' => esc_html__('Center', 'ratchet'),
				'flex-start' => esc_html__('Flex Start', 'ratchet'),
				'flex-end' => esc_html__('Flex End', 'ratchet'),
				'space-around' => esc_html__('Space Around', 'ratchet'),
				'space-between' => esc_html__('Space Between', 'ratchet'),
				'space-evenly' => esc_html__('Space Evenly', 'ratchet'),
			],
			'mobile_options' => true,
			'toggle_slug' => 'flexbox',
		];
			
		$fields["flex_gap"] = [
			'label' => esc_html__('Gap', 'ratchet'),
			'type' => 'range',
			'option_category' => 'configuration',
			'default' => '20px',
			'default_unit' => 'px',
			'default_on_front' => '20px',
			'allowed_units' => ['%', 'em', 'rem', 'px', 'cm', 'mm', 'in', 'pt', 'pc', 'ex', 'vh', 'vw'],
			'range_settings' => [
				'min' => '0',
				'max' => '150',
				'step' => '1',
			],
			'hover' => 'tabs',
			'validate_unit' => true,
			'toggle_slug' => 'flexbox',
		];
		
		$fields['align_items'] = [
			'label' => esc_html__('Align Items', 'ratchet'),
			'type' => 'select',
			'option_category' => 'configuration',
			'default' => 'baseline',
			'options' => [
				'baseline' => esc_html__('Baseline', 'ratchet'),
				'center' => esc_html__('Center', 'ratchet'),
				'flex-start' => esc_html__('Flex Start', 'ratchet'),
				'flex-end' => esc_html__('Flex End', 'ratchet'),
			],
			'mobile_options' => true,
			'toggle_slug' => 'flexbox',
		];
		
		return $fields;
	}
	
	protected function mw_get_responsive_prop($property, $default = '', $default_if_empty = true, $base_name = '')
	{
		$responsive_prop = [];
		$responsive_enabled = isset($this->props["{$property}_last_edited"]) ? et_pb_get_responsive_status($this->props["{$property}_last_edited"]) : false;
	
		if (!empty($base_name)) {
			$responsive_enabled = isset($this->props["{$base_name}_last_edited"]) ? et_pb_get_responsive_status($this->props["{$base_name}_last_edited"]) : false;
		}
	
		if (!isset($this->props[$property]) || ($default_if_empty && '' === $this->props[$property])) {
			$responsive_prop["desktop"] = $default;
		} else {
			$responsive_prop["desktop"] = $this->props[$property];
		}
	
		if (!$responsive_enabled || !isset($this->props["{$property}_tablet"]) || '' === $this->props["{$property}_tablet"]) {
			$responsive_prop["tablet"] = $responsive_prop["desktop"];
		} else {
			$responsive_prop["tablet"] = $this->props["{$property}_tablet"];
		}
	
		if (!$responsive_enabled || !isset($this->props["{$property}_phone"]) || '' === $this->props["{$property}_phone"]) {
			$responsive_prop["phone"] = $responsive_prop["tablet"];
		} else {
			$responsive_prop["phone"] = $this->props["{$property}_phone"];
		}
	
		return $responsive_prop;
	}

	public function render($attrs, $content, $render_slug)
	{
		$flex_direction = $this->mw_get_responsive_prop('flex_direction');
		$justify_content = $this->mw_get_responsive_prop('justify_content');
		$align_items = $this->mw_get_responsive_prop('align_items');
		$flex_wrap_on = $this->mw_get_responsive_prop('flex_wrap');
		
		$css_values = array(
			'desktop' => array(
				'flex-direction' => esc_html($flex_direction['desktop']),
				'justify-content' => esc_html($justify_content['desktop']),
				'align-items' => esc_html($align_items['desktop']),
				'flex-wrap' => esc_html($flex_wrap_on['desktop'] === 'on' ? 'wrap' : 'nowrap'),
			),
			'tablet' => array(
				'flex-direction' => esc_html($flex_direction['tablet']),
				'justify-content' => esc_html($justify_content['tablet']),
				'align-items' => esc_html($align_items['tablet']),
				'flex-wrap' => esc_html($flex_wrap_on['tablet'] === 'on' ? 'wrap' : 'nowrap'),
			),
			'phone' => array(
				'flex-direction' => esc_html($flex_direction['phone']),
				'justify-content' => esc_html($justify_content['phone']),
				'align-items' => esc_html($align_items['phone']),
				'flex-wrap' => esc_html($flex_wrap_on['phone'] === 'on' ? 'wrap' : 'nowrap'),
			),
		);
		et_pb_responsive_options()->generate_responsive_css($css_values, '%%order_class%%', '', $render_slug, '', 'flex');

		$output = sprintf(
			'<div %2$s class="%3$s button_grid">
				%1$s
			</div>',
			et_core_sanitized_previously($this->content),
			$this->module_id(),
			$this->module_classname( $render_slug )
		);
		
		$display = "display: flex;";
		ET_Builder_Element::set_style(
			$function_name,
			array(
				'selector'    => ".button_grid",
				'declaration' => $display,
			)
		);
		
		$fix_margins = "margin-bottom: 0 !important;";
		ET_Builder_Element::set_style(
			$function_name,
			array(
				'selector'    => ".button_grid > div",
				'declaration' => $fix_margins,
			)
		);
		
		$flex_gap = $this->props['flex_gap'];
		if($flex_gap == ''){
			$gap = "gap: 20px;";
		}else{
			$gap = "gap: $flex_gap;";
		}
		
		ET_Builder_Element::set_style(
			$function_name,
			array(
				'selector'    => ".button_grid",
				'declaration' => $gap,
			)
		);
		
		ET_Builder_Element::set_style(
			$function_name,
			array(
				'selector'    => ".button_grid .et_pb_button.button-wrap",
				'declaration' => "display: block;",
			)
		);

		return $output;
	}
}
new Button_Grid_Module;